# aws_recommendations

aws_recommendations package gives recommendation for you aws account

Release Notes:
# v0.0.10
1. Added methods for following recommendations:
   - Low Utilization Amazon EC2 Instances
   - Underutilized Amazon Redshift Clusters
   - idle ebs volumes
   - Idle elb
   - enable s3 bucket keys
   - rds_general_purpose_ssd
   - ebs_general_purpose_ssd
   - unused_ami

# v0.0.7
1. Added methods for new recommendations
2. Added following methods:
   1. reserved_instance_lease_expiration()
   2. unassociated_elastic_ip_addresses()
   3. rds_idle_db_instances()

# v0.0.3
1. Minor bug fixes

# v0.0.2
1. Improved code quality
2. Multi region now supported

# v0.0.1 - Initial Release
